==> ?download=%2Fupload%2Fversions%2FDZIRCMS-2.2.0.zip: admin/includes/include.mod_html.php <==
<?php
/**
 * Project: 
 * DZIRCMS Content Management System
 * 
 * Description: 
 * Edit file
 * 
 * Requirements: 
 * @con_php_req 7.0
 * 
 *
 * @package    DZIRCMS Backend includes
 * @version    1.0.0
 * @author     René Mansveld
 * @copyright  Spider IT Deutschland
 * @license    https://www.dzir.org/license/LIZENZ.txt
 * @link       https://www.spider-it.de
 * @link       https://www.dzir.org
 * @since      file available since DZIRCMS 2.2.0
 * 
 * {@internal 
 *   created 2022-10-19
 * }
 */

if (!defined('CON_FRAMEWORK')) {
    die('Illegal call');
}

cInclude("external", "edit_area/class.edit_area.php");
cInclude('includes', 'functions.upl.php');
cInclude('includes', 'functions.file.php');

$aFileTypes = array('*.html', '*.tpl');

$sActionCreate = 'mod_new_html';
$sActionDelete = 'mod_delete_html';
$sActionEdit = 'save_file';
$action = $_REQUEST['action'];

$page = new cPage;
$page->setEncoding("utf-8");

if (!$perm->have_perm_area_action($area, $action)) {
    $notification->displayNotification("error", i18n("Permission denied"));
}
elseif ((int) $client == 0) {

    #if there is no client selected, display empty page
    $page->render();
}
else {
    $page->addScript('jQuery', '<script src="scripts/jquery/jquery.js"></script>');

    $idmod = (int) $_REQUEST['idmod'];
    $oModule = new cApiModule($idmod);
    $sPath = $cfgClient[$client]['path']['frontend'] . 'data/modules/' . uplCreateFriendlyName($oModule->get('name')) . '/html/';
    $sInfoPath = '../data/modules/' . uplCreateFriendlyName($oModule->get('name')) . '/html/';

    if (($action == $sActionCreate)) {
        $sLoadFile = '';
    }
    elseif (($action == $sActionDelete) && (strlen($_REQUEST['file']))) {
        $sOrigFileName = $_REQUEST['file'];
        $sTypeContent = substr($sOrigFileName, (strrpos($sOrigFileName, '.') + 1));
        removeFileInformation($client, $sInfoPath . $sOrigFileName, $sTypeContent, $db);
        unlink($sPath . $sOrigFileName);
    }
    elseif (($action == $sActionEdit) && (strlen($_POST['tmp_file'])) && ($_POST['status'] == 'send')) {
        $sOrigFileName = $_POST['tmp_file'];
        $sLoadFile = $_POST['file'];
        if ($sOrigFileName != $sLoadFile) {

            # The filename was changed, rename the file
            $sLoadFile = renameFile($sOrigFileName, $sLoadFile, $sPath);
        }

        $sTypeContent = substr($sOrigFileName, (strrpos($sOrigFileName, '.') + 1));
        $aFileInfo = getFileInformation($client, $sInfoPath . $sOrigFileName, $sTypeContent, $db);

        updateFileInformation($client, $sInfoPath . $sOrigFileName, $sTypeContent, $auth->auth['uid'], $_REQUEST['description'], $db, $sInfoPath . $sLoadFile);

        $bEdit = fileEdit($sLoadFile, $_REQUEST['code'], $sPath);
    }
    elseif (($action == $sActionEdit) && (!strlen($_POST['tmp_file'])) && ($_POST['status'] == 'send')) {
        $sLoadFile = $_POST['file'];
    	$sOrigFileName = $sLoadFile;
    	createFile($sLoadFile, $sPath);
    	$bEdit = fileEdit($sLoadFile, $_REQUEST['code'], $sPath);
        $sTypeContent = substr($sOrigFileName, (strrpos($sOrigFileName, '.') + 1));
        updateFileInformation($client, $sInfoPath . $sLoadFile, $sTypeContent, $auth->auth['uid'], $_REQUEST['description'], $db);
    }
    elseif (strlen($_REQUEST['file'])) {
        $sLoadFile = $_REQUEST['file'];
    }

    $aFiles = getFilesInDirectory($sPath, $aFileTypes, SORT_ASC);

    $oForm1 = new UI_Table_Form('choose_file');
    $oForm1->addHeader(i18n("Select file"));
    $oForm1->setWidth("300");
    $oForm1->setVar("area", $area);
    $oForm1->setVar('idmod', $idmod);
    $oForm1->setVar("frame", $frame);
    $oForm1->setVar("status", 'send');

    $oForm1->add(i18n("Action"), '<a href="main.php?area=' . $area . '&action=mod_new_html&idmod=' . $idmod . '&frame=4&contenido=' . $contenido . '" style="display: inline-block; padding-left: 18px; line-height: 16px; background: url(\'images/but_art_new.gif\') left center no-repeat;"> ' . i18n("New html file") . '</a>');

    if (count($aFiles)) {
        $oForm1->add(i18n("Action"), '<a id="Delete" href="." style="display: inline-block; padding-left: 18px; line-height: 16px; background: url(\'images/but_delete.gif\') left center no-repeat;"> ' . i18n("Delete html file") . '</a>');
        $sDeleteScript = '<script>
    $(document).ready(function() {
        $("#Delete").click(function(e) {
            e.preventDefault();
            if (confirm("' . str_replace(array('<br>', '<br/>', '<br />'), '\n', i18n("Do you really want to delete the following file:<br>")) . '" + $("[name=\'file\']").val())) {
                document.location.href = "main.php?area=' . $area . '&action=mod_delete_html&file=" + $("[name=\'file\']").val() + "&idmod=' . $idmod . '&frame=4&contenido=' . $contenido . '";
            }
        });
    });
</script>';
        $page->addScript('delete', $sDeleteScript);
        
        $oFiles = new cHTMLSelectElement('file', '100%');
        foreach ($aFiles as $key => $sFile) {
            $oFiles->addOptionElement($key, new cHtmlOptionElement($sFile, $sFile, ($sFile == $sLoadFile)));
        }
        $oForm1->add(i18n("File"), $oFiles);

        if (!isset($sLoadFile)) {
            $sLoadFile = $aFiles[0];
        }
        $oForm2 = new UI_Table_Form('edit_file');
        $oForm2->addHeader(i18n("Edit file"));
        $oForm2->setWidth('100%');
        $oForm2->setVar("area", $area);
        $oForm2->setVar("action", $sActionEdit);
        $oForm2->setVar('idmod', $idmod);
        $oForm2->setVar("frame", $frame);
        $oForm2->setVar("status", 'send');
        $oForm2->setVar("tmp_file", $sLoadFile);

        $tb_name = new cHTMLTextbox("file", $sLoadFile, 60);

        $sCode = getFileContent($sPath . $sLoadFile, $path);
        $ta_code = new cHTMLTextarea("code", htmlspecialchars($sCode), 100, 35, "code");
        $ta_code->setStyle("font-family: monospace; width: 100%;");
        $ta_code->updateAttributes(array("wrap" => getEffectiveSetting('style_editor', 'wrap', 'off')));

        $sTypeContent = substr($sLoadFile, (strrpos($sLoadFile, '.') + 1));
        $aFileInfo = getFileInformation($client, $sInfoPath . $sLoadFile, $sTypeContent, $db);
        $descr = new cHTMLTextarea("description", htmlspecialchars($aFileInfo["description"]), 100, 5);
        $descr->setStyle("font-family: monospace; width: 100%;");

        $oForm2->add(i18n("Name"), $tb_name);
        $oForm2->add(i18n("Description"), $descr->render());
        $oForm2->add(i18n("Code"), $ta_code);            

        $oEditArea = new EditArea('code', 'html', substr(strtolower($belang), 0, 2), true, $cfg);
        $page->addScript('editarea', $oEditArea->renderScript());
    }
    $page->setContent($oForm1->render() . ((count($aFiles)) ? '<br>' . $oForm2->render() : ''));

    $page->render();
}
?>

==> ?download=%2Fupload%2Fversions%2FDZIRCMS-2.3.2.zip: admin/includes/include.mod_html.php <==
<?php
/**
 * Project: 
 * DZIRCMS Content Management System
 * 
 * Description: 
 * Edit file
 * 
 * Requirements: 
 * @con_php_req 7.0
 * 
 *
 * @package    DZIRCMS Backend includes
 * @version    1.0.0
 * @author     René Mansveld
 * @copyright  Spider IT Deutschland
 * @license    https://www.dzir.org/license/LIZENZ.txt
 * @link       https://www.spider-it.de
 * @link       https://www.dzir.org
 * @since      file available since DZIRCMS 2.2.0
 * 
 * {@internal 
 *   created 2022-10-19
 * }
 */

if (!defined('CON_FRAMEWORK')) {
    die('Illegal call');
}

cInclude("external", "edit_area/class.edit_area.php");
cInclude('includes', 'functions.upl.php');
cInclude('includes', 'functions.file.php');

$aFileTypes = array('*.html', '*.tpl');

$sActionCreate = 'mod_new_html';
$sActionDelete = 'mod_delete_html';
$sActionEdit = 'save_file';
$action = $_REQUEST['action'];

$page = new cPage;
$page->setEncoding("utf-8");

if (!$perm->have_perm_area_action($area, $action)) {
    $notification->displayNotification("error", i18n("Permission denied"));
}
elseif ((int) $client == 0) {

    #if there is no client selected, display empty page
    $page->render();
}
else {
    $page->addScript('jQuery', '<script src="scripts/jquery/jquery.js"></script>');

    $idmod = (int) $_REQUEST['idmod'];
    $oModule = new cApiModule($idmod);
    $sPath = $cfgClient[$client]['path']['frontend'] . 'data/modules/' . uplCreateFriendlyName($oModule->get('name')) . '/templates/';
    $sInfoPath = '../data/modules/' . uplCreateFriendlyName($oModule->get('name')) . '/templates/';

    if (($action == $sActionCreate)) {
        $sLoadFile = '';
    }
    elseif (($action == $sActionDelete) && (strlen($_REQUEST['file']))) {
        $sOrigFileName = $_REQUEST['file'];
        $sTypeContent = substr($sOrigFileName, (strrpos($sOrigFileName, '.') + 1));
        removeFileInformation($client, $sInfoPath . $sOrigFileName, $sTypeContent, $db);
        unlink($sPath . $sOrigFileName);
    }
    elseif (($action == $sActionEdit) && (strlen($_POST['tmp_file'])) && ($_POST['status'] == 'send')) {
        $sOrigFileName = $_POST['tmp_file'];
        $sLoadFile = $_POST['file'];
        if ($sOrigFileName != $sLoadFile) {

            # The filename was changed, rename the file
            $sLoadFile = renameFile($sOrigFileName, $sLoadFile, $sPath);
        }

        $sTypeContent = substr($sOrigFileName, (strrpos($sOrigFileName, '.') + 1));
        $aFileInfo = getFileInformation($client, $sInfoPath . $sOrigFileName, $sTypeContent, $db);

        updateFileInformation($client, $sInfoPath . $sOrigFileName, $sTypeContent, $auth->auth['uid'], $_REQUEST['description'], $db, $sInfoPath . $sLoadFile);

        $bEdit = fileEdit($sLoadFile, $_REQUEST['code'], $sPath);
    }
    elseif (($action == $sActionEdit) && (!strlen($_POST['tmp_file'])) && ($_POST['status'] == 'send')) {
        $sLoadFile = $_POST['file'];
    	$sOrigFileName = $sLoadFile;
    	createFile($sLoadFile, $sPath);
    	$bEdit = fileEdit($sLoadFile, $_REQUEST['code'], $sPath);
        $sTypeContent = substr($sOrigFileName, (strrpos($sOrigFileName, '.') + 1));
        updateFileInformation($client, $sInfoPath . $sLoadFile, $sTypeContent, $auth->auth['uid'], $_REQUEST['description'], $db);
    }
    elseif (strlen($_REQUEST['file'])) {
        $sLoadFile = $_REQUEST['file'];
    }

    $aFiles = getFilesInDirectory($sPath, $aFileTypes, SORT_ASC);

    $oForm1 = new UI_Table_Form('choose_file');
    $oForm1->addHeader(i18n("Select file"));
    $oForm1->setWidth("300");
    $oForm1->setVar("area", $area);
    $oForm1->setVar('idmod', $idmod);
    $oForm1->setVar("frame", $frame);
    $oForm1->setVar("status", 'send');

    $oForm1->add(i18n("Action"), '<a href="main.php?area=' . $area . '&action=mod_new_html&idmod=' . $idmod . '&frame=4&contenido=' . $contenido . '" style="display: inline-block; padding-left: 18px; line-height: 16px; background: url(\'images/but_art_new.gif\') left center no-repeat;"> ' . i18n("New html file") . '</a>');

    if (count($aFiles)) {
        $oForm1->add(i18n("Action"), '<a id="Delete" href="." style="display: inline-block; padding-left: 18px; line-height: 16px; background: url(\'images/but_delete.gif\') left center no-repeat;"> ' . i18n("Delete html file") . '</a>');
        $sDeleteScript = '<script>
    $(document).ready(function() {
        $("#Delete").click(function(e) {
            e.preventDefault();
            if (confirm("' . str_replace(array('<br>', '<br/>', '<br />'), '\n', i18n("Do you really want to delete the following file:<br>")) . '" + $("[name=\'file\']").val())) {
                document.location.href = "main.php?area=' . $area . '&action=mod_delete_html&file=" + $("[name=\'file\']").val() + "&idmod=' . $idmod . '&frame=4&contenido=' . $contenido . '";
            }
        });
    });
</script>';
        $page->addScript('delete', $sDeleteScript);
        
        $oFiles = new cHTMLSelectElement('file', '100%');
        foreach ($aFiles as $key => $sFile) {
            $oFiles->addOptionElement($key, new cHtmlOptionElement($sFile, $sFile, ($sFile == $sLoadFile)));
        }
        $oForm1->add(i18n("File"), $oFiles);

        if (!isset($sLoadFile)) {
            $sLoadFile = $aFiles[0];
        }
        $oForm2 = new UI_Table_Form('edit_file');
        $oForm2->addHeader(i18n("Edit file"));
        $oForm2->setWidth('100%');
        $oForm2->setVar("area", $area);
        $oForm2->setVar("action", $sActionEdit);
        $oForm2->setVar('idmod', $idmod);
        $oForm2->setVar("frame", $frame);
        $oForm2->setVar("status", 'send');
        $oForm2->setVar("tmp_file", $sLoadFile);

        $tb_name = new cHTMLTextbox("file", $sLoadFile, 60);

        $sCode = getFileContent($sPath . $sLoadFile, $path);
        $ta_code = new cHTMLTextarea("code", htmlspecialchars($sCode), 100, 35, "code");
        $ta_code->setStyle("font-family: monospace; width: 100%;");
        $ta_code->updateAttributes(array("wrap" => getEffectiveSetting('style_editor', 'wrap', 'off')));

        $sTypeContent = substr($sLoadFile, (strrpos($sLoadFile, '.') + 1));
        $aFileInfo = getFileInformation($client, $sInfoPath . $sLoadFile, $sTypeContent, $db);
        $descr = new cHTMLTextarea("description", htmlspecialchars($aFileInfo["description"]), 100, 5);
        $descr->setStyle("font-family: monospace; width: 100%;");

        $oForm2->add(i18n("Name"), $tb_name);
        $oForm2->add(i18n("Description"), $descr->render());
        $oForm2->add(i18n("Code"), $ta_code);            

        $oEditArea = new EditArea('code', 'html', substr(strtolower($belang), 0, 2), true, $cfg);
        $page->addScript('editarea', $oEditArea->renderScript());
    }
    $page->setContent($oForm1->render() . ((count($aFiles)) ? '<br>' . $oForm2->render() : ''));

    $page->render();
}
?>
